@@ -1,4 +1,4 @@
-from xml.dom import minidom
+from lxml import etree
 import os
 
 class KRecipes:
@@ -12,9 +12,12 @@ class KRecipes:
             for item in data:
                 if item.startswith("<?xml"):
                     xmlstring = item
-                    xml_document = minidom.parseString(xmlstring)
+                    xml_document = etree.XML(xmlstring)
         else:
-            xml_document = minidom.parse(filename)
+            f = open(filename, 'r')
+            doc = f.read()
+            f.close()
+            xml_document = etree.XML(doc)
 
         title_list, category_list, preptime_list, servings_list, ing_list, \
                 instructions_list, picture_list = self.xml_load(xml_document)
@@ -64,84 +67,69 @@ class KRecipes:
         instructions_list = []
         picture_list = []
         idd = 0
-        for node in xml_document.documentElement.childNodes:
-            if node.nodeName == 'krecipes-recipe':
-                for item_node in node.childNodes:
-                    if item_node.nodeName == 'krecipes-description':
-                        for desc_nodes in item_node.childNodes:
-                            if desc_nodes.nodeName == 'title':
+
+        for i in xml_document.getchildren():
+            if 'krecipes-recipe' in i.tag:
+                for j in i.getchildren():
+                    if 'krecipes-description' in j.tag:
+                        for k in j.getchildren():
+                            if 'title' in k.tag:
                                 idd += 1
-                                tup = [idd, desc_nodes.firstChild.nodeValue]
+                                tup = [idd, k.text]
                                 title_list.append(tup)
-                            elif desc_nodes.nodeName == 'category':
-                                for categ_node in desc_nodes.childNodes:
-                                    if categ_node.nodeName == 'cat':
-                                        if categ_node.firstChild is None:
-                                            pass
-                                        else:
-                                            tup = [idd, categ_node.firstChild.nodeValue]
+                            elif 'category' in k.tag:
+                                for l in k.getchildren():
+                                    if 'cat' in l.tag:
+                                        if l.text is not None:
+                                            tup = [idd, l.text]
                                             category_list.append(tup)
                                             #Just get the first available category
                                             break
-                            elif desc_nodes.nodeName == 'preparation-time':
-                                if desc_nodes.firstChild is None:
-                                    pass
-                                else:
-                                    tup = [idd, desc_nodes.firstChild.nodeValue]
+                            elif 'preparation-time' in k.tag:
+                                if k.text is not None:
+                                    tup = [idd, k.text]
                                     preptime_list.append(tup)
-                            elif desc_nodes.nodeName == 'yield':
-                                for yield_node in desc_nodes.childNodes:
-                                    if yield_node.firstChild is None:
-                                        continue
-                                    if yield_node.nodeName == "amount":
-                                        amserv = yield_node.firstChild.nodeValue
-                                    if yield_node.firstChild.nodeValue == "Servings":
+                            elif 'yield' in k.tag:
+                                for l in k.getchildren():
+                                    if "amount" in l.tag:
+                                        amserv = l.text
+                                    if "Servings" in l.tag:
                                         tup = [idd, amserv]
                                         servings_list.append(tup)
-                            elif desc_nodes.nodeName == 'pictures':
-                                for pict_node in desc_nodes.childNodes:
-                                    if pict_node.nodeName == 'pic':
-                                        if pict_node.firstChild is None:
-                                            pass
-                                        else:
-                                            tup = [idd, pict_node.firstChild.nodeValue]
+                            elif 'pictures' in k.tag:
+                                for l in k.getchildren():
+                                    if 'pic' in l.tag:
+                                        if l.text is not None:
+                                            tup = [idd, l.text]
                                             picture_list.append(tup)
                                             #Just get the first available pic
                                             break
-                    elif item_node.nodeName == 'krecipes-ingredients':
+                    elif 'krecipes-ingredients' in j.tag:
                         one_item = ''
                         new_list = []
-                        for each_node in item_node.childNodes:
-                            if each_node.nodeName == 'ingredient':
-                                for new_nodes in each_node.childNodes:
-                                    if new_nodes.nodeName == 'name':
-                                        if new_nodes.firstChild is None:
-                                            pass
-                                        else:
-                                            item = new_nodes.firstChild.nodeValue.replace('\t', '').replace('\n', '')
+                        for k in j.getchildren():
+                            if 'ingredient' in k.tag:
+                                for l in k.getchildren():
+                                    if 'name' in l.tag:
+                                        if l.text is not None:
+                                            item = l.text.replace('\t', '').replace('\n', '')
                                             one_item = one_item + item + '\n'
-                                    elif new_nodes.nodeName == 'amount':
-                                        if new_nodes.firstChild.nodeValue is None:
-                                            pass
-                                        else:
-                                            amount = new_nodes.firstChild.nodeValue.replace('\t', '').replace('\n', '')
+                                    elif 'amount' in l.tag:
+                                        if l.text is not None:
+                                            amount = l.text.replace('\t', '').replace('\n', '')
                                             one_item = amount + '||<unit>||' + one_item
-                                    elif new_nodes.nodeName == 'unit':
-                                        if new_nodes.firstChild is None:
-                                            pass
-                                        else:
-                                            unit = new_nodes.firstChild.nodeValue.replace('\t', '').replace('\n', '')
+                                    elif 'unit' in l.tag:
+                                        if l.text is not None:
+                                            unit = l.text.replace('\t', '').replace('\n', '')
                                             one_item = one_item.replace('<unit>', unit)
                                 one_item = self.tratar_one_ing(one_item)
                                 new_list.append(one_item)
                                 one_item = ''
                         tup = [idd, ('').join(new_list)]
                         ing_list.append(tup)
-                    elif item_node.nodeName == 'krecipes-instructions':
-                        if item_node.firstChild is None:
-                            pass
-                        else:
-                            tup = [idd, item_node.firstChild.nodeValue]
+                    elif 'krecipes-instructions' in j.tag:
+                        if j.text is not None:
+                            tup = [idd, j.text]
                             instructions_list.append(tup)
 
         return title_list, category_list, preptime_list, \
